aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorGravatar Dessa2016-01-31 19:36:37 +0100
committerGravatar Dessa2016-01-31 19:36:37 +0100
commit07867e9e4caf28738fb613c803c385f368db433e (patch)
tree2bdf9e8e5401c899cb5d72063ace1213ef174a30 /src
parentMerge pull request #1858 from bsdjunk/master (diff)
downloadKVIrc-07867e9e4caf28738fb613c803c385f368db433e.tar.gz
KVIrc-07867e9e4caf28738fb613c803c385f368db433e.tar.bz2
KVIrc-07867e9e4caf28738fb613c803c385f368db433e.zip
run codespell to fix some typos, run mkabouttext.pl, fix typos reported by Arfrever
Diffstat (limited to 'src')
-rw-r--r--src/kvilib/config/kvi_defaults.h2
-rw-r--r--src/kvilib/core/KviCString.cpp8
-rw-r--r--src/kvilib/core/KviCString.h30
-rw-r--r--src/kvilib/core/KviPointerHashTable.h22
-rw-r--r--src/kvilib/core/KviQString.cpp2
-rw-r--r--src/kvilib/ext/KviAnimatedPixmapCache.h2
-rw-r--r--src/kvilib/ext/KviConfigurationFile.cpp2
-rw-r--r--src/kvilib/ext/KviMediaManager.cpp4
-rw-r--r--src/kvilib/ext/KviOggTheoraEncoder.h4
-rw-r--r--src/kvilib/irc/KviIrcUserEntry.cpp2
-rw-r--r--src/kvilib/locale/KviLocale.h2
-rw-r--r--src/kvilib/net/KviDnsResolverNew.h2
-rw-r--r--src/kvilib/system/KviByteOrder.h6
-rw-r--r--src/kvilib/system/KviThread.cpp4
-rw-r--r--src/kvilib/system/KviTimeUtils.h2
-rw-r--r--src/kvirc/kernel/KviApplication.cpp6
-rw-r--r--src/kvirc/kernel/KviIconManager.cpp12
-rw-r--r--src/kvirc/kernel/KviIconManager.h6
-rw-r--r--src/kvirc/kernel/KviIrcConnection.h8
-rw-r--r--src/kvirc/kernel/KviIrcConnectionServerInfo.h2
-rw-r--r--src/kvirc/kernel/KviIrcConnectionStateData.h2
-rw-r--r--src/kvirc/kernel/KviIrcUrl.cpp2
-rw-r--r--src/kvirc/kernel/KviOptions.h2
-rw-r--r--src/kvirc/kvs/KviKvsArray.cpp2
-rw-r--r--src/kvirc/kvs/KviKvsCoreCallbackCommands.cpp2
-rw-r--r--src/kvirc/kvs/KviKvsCoreFunctions_gl.cpp4
-rw-r--r--src/kvirc/kvs/KviKvsCoreFunctions_mr.cpp4
-rw-r--r--src/kvirc/kvs/KviKvsCoreFunctions_sz.cpp2
-rw-r--r--src/kvirc/kvs/KviKvsCoreSimpleCommands_af.cpp28
-rw-r--r--src/kvirc/kvs/KviKvsCoreSimpleCommands_gl.cpp6
-rw-r--r--src/kvirc/kvs/KviKvsCoreSimpleCommands_mr.cpp18
-rw-r--r--src/kvirc/kvs/KviKvsCoreSimpleCommands_sz.cpp18
-rw-r--r--src/kvirc/kvs/KviKvsUserAction.h2
-rw-r--r--src/kvirc/kvs/event/KviKvsEventHandler.h2
-rw-r--r--src/kvirc/kvs/parser/KviKvsParser.cpp14
-rw-r--r--src/kvirc/kvs/tree/KviKvsTreeNodeCompositeData.cpp2
-rw-r--r--src/kvirc/kvs/tree/KviKvsTreeNodeDataList.cpp2
-rw-r--r--src/kvirc/kvs/tree/KviKvsTreeNodeInstructionBlock.cpp2
-rw-r--r--src/kvirc/module/KviModule.cpp2
-rw-r--r--src/kvirc/sparser/KviIrcServerParser_ctcp.cpp2
-rw-r--r--src/kvirc/sparser/KviIrcServerParser_numericHandlers.cpp8
-rw-r--r--src/kvirc/ui/KviChannelWindow.h4
-rw-r--r--src/kvirc/ui/KviIpEditor.cpp2
-rw-r--r--src/kvirc/ui/KviIrcView.cpp2
-rw-r--r--src/kvirc/ui/KviMainWindow.cpp2
-rw-r--r--src/kvirc/ui/KviStatusBar.h2
-rw-r--r--src/modules/about/ENTRIES6
-rw-r--r--src/modules/about/abouttext.inc12
-rwxr-xr-x[-rw-r--r--]src/modules/about/mkabouttext.pl0
-rw-r--r--src/modules/avatar/libkviavatar.cpp2
-rw-r--r--src/modules/classeditor/ClassEditorWindow.h2
-rw-r--r--src/modules/dcc/DccMarshal.cpp2
-rw-r--r--src/modules/dcc/DccVoiceAdpcmCodec.cpp2
-rw-r--r--src/modules/dcc/libkvidcc.cpp2
-rw-r--r--src/modules/filetransferwindow/FileTransferWindow.cpp2
-rw-r--r--src/modules/mediaplayer/MpMprisInterface.cpp10
-rw-r--r--src/modules/mediaplayer/libkvimediaplayer.cpp2
-rw-r--r--src/modules/objects/KvsObject_label.cpp2
-rw-r--r--src/modules/objects/KvsObject_listWidget.cpp2
-rw-r--r--src/modules/objects/KvsObject_radioButton.cpp2
-rw-r--r--src/modules/objects/KvsObject_socket.cpp2
-rw-r--r--src/modules/options/OptionsInstanceManager.cpp2
-rwxr-xr-xsrc/modules/options/mkcreateinstanceproc.sh2
-rw-r--r--src/modules/perl/libkviperl.cpp4
-rw-r--r--src/modules/perlcore/CMakeLists.txt2
-rw-r--r--src/modules/python/libkvipython.cpp4
-rw-r--r--src/modules/str/libkvistr.cpp2
-rw-r--r--src/modules/torrent/libkvitorrent.cpp2
-rw-r--r--src/modules/window/libkviwindow.cpp4
69 files changed, 169 insertions, 169 deletions
diff --git a/src/kvilib/config/kvi_defaults.h b/src/kvilib/config/kvi_defaults.h
index a94b297f3..853683142 100644
--- a/src/kvilib/config/kvi_defaults.h
+++ b/src/kvilib/config/kvi_defaults.h
@@ -47,7 +47,7 @@
* \def KVI_DEFAULT_CTCP_PAGE_REPLY Reply to CTCP PAGE
* \def KVI_DEFAULT_AWAY_MESSAGE Away message
* \def KVI_DEFAULT_AWAY_NICK Nickname when in away mode
-* \def KVI_MAX_PENDING_AVATARS Maximum number of avatars to download simultanously
+* \def KVI_MAX_PENDING_AVATARS Maximum number of avatars to download simultaneously
* \def KVI_MAX_RECENT_SERVERS Maximum number of servers to hold in "recent" menu
* \def KVI_MAX_RECENT_CHANNELS Maximum number of channels to hold in "recent" menu
* \def KVI_MAX_RECENT_NICKNAMES Maximum number of nicknames to hold in "recent" menu
diff --git a/src/kvilib/core/KviCString.cpp b/src/kvilib/core/KviCString.cpp
index 8a7c19241..ec7257165 100644
--- a/src/kvilib/core/KviCString.cpp
+++ b/src/kvilib/core/KviCString.cpp
@@ -2159,7 +2159,7 @@ KviCString & KviCString::transliterate(const char * szToFind,const char * szRepl
}
-int KviCString::occurences(char c,bool caseS) const
+int KviCString::occurrences(char c,bool caseS) const
{
char *p = m_ptr;
int cnt=0;
@@ -2178,7 +2178,7 @@ int KviCString::occurences(char c,bool caseS) const
return cnt;
}
-int KviCString::occurences(const char *str,bool caseS) const
+int KviCString::occurrences(const char *str,bool caseS) const
{
KVI_ASSERT(str);
char *p = m_ptr;
@@ -2888,7 +2888,7 @@ int KviCString::findLastIdx(const char *str,bool caseS) const
//go back until we find a character that mathes or we run to the first char.
while((*p != *str) && (p > m_ptr))p--;
if(*p == *str){
- //maybe occurence....
+ //maybe occurrence....
if(kvi_strEqualCSN(str,p,len))return (p-m_ptr);
else {
//Nope...continue if there is more data to check...
@@ -2904,7 +2904,7 @@ int KviCString::findLastIdx(const char *str,bool caseS) const
char tmp = toupper(*str);
while((toupper(*p) != tmp) && (p > m_ptr))p--;
if(toupper(*p) == tmp){
- //maybe occurence....
+ //maybe occurrence....
if(kvi_strEqualCIN(str,p,len))return (p-m_ptr);
else {
//Nope...continue if there is more data to check...
diff --git a/src/kvilib/core/KviPointerHashTable.h b/src/kvilib/core/KviPointerHashTable.h
index 1d95ab3c5..d2dad1bde 100644
--- a/src/kvilib/core/KviPointerHashTable.h
+++ b/src/kvilib/core/KviPointerHashTable.h
@@ -417,14 +417,14 @@ public:
* For other Key types the case sensitive flag has no meaning and will
* (hopefully) be optimized out by the compiler.
*
-* For pointer based keys the hash table may or may not mantain deep copies of
+* For pointer based keys the hash table may or may not maintain deep copies of
* Key data. For example, with char * keys, if deep copying is enabled then a
-* private copy of the string data will be mantained. With deep copying
+* private copy of the string data will be maintained. With deep copying
* disabled only char * pointers will be kept. For types that do not have
* meaning of deep copy the deep copying code will (hopefully) be optimized
* out by the compiler.
*
-* The hashtable mantains an array of KviPointerList based buckets.
+* The hashtable maintains an array of KviPointerList based buckets.
* The number of buckets may be specified by the application user and does NOT
* need to be a prime number. Yet better to have it a power of two so the
* memory allocation routines will feel better and are less likely to waste
@@ -581,12 +581,12 @@ public:
}
/**
- * \brief Removes the first occurence of the item pointer pRef.
+ * \brief Removes the first occurrence of the item pointer pRef.
*
* The item is deleted if autodeletion is enabled. Returns true if the
* pointer was found and false otherwise.
* Invalidates the hash table iterator.
- * \param pRef The pointer to remove the first occurence
+ * \param pRef The pointer to remove the first occurrence
* \return bool
*/
bool removeRef(const T * pRef)
@@ -678,7 +678,7 @@ public:
/**
* \brief Returns the entry pointed by the hash table iterator.
*
- * This function must be preceeded by a call to firstEntry(), first()
+ * This function must be preceded by a call to firstEntry(), first()
* or findRef().
* \return KviPointerHashTableEntry<Key,T> *
*/
@@ -707,7 +707,7 @@ public:
/**
* \brief Places the hash table iterator at the next entry and returns it.
*
- * This function must be preceeded by a call to firstEntry(), first()
+ * This function must be preceded by a call to firstEntry(), first()
* or findRef().
* \return KviPointerHashTableEntry<Key,T> *
*/
@@ -737,7 +737,7 @@ public:
/**
* \brief Returns the data value pointer pointed by the hash table iterator.
*
- * This function must be preceeded by a call to firstEntry(), first()
+ * This function must be preceded by a call to firstEntry(), first()
* or findRef().
* \return T *
*/
@@ -756,7 +756,7 @@ public:
/**
* \brief Returns the key pointed by the hash table iterator.
*
- * This function must be preceeded by a call to firstEntry(), first()
+ * This function must be preceded by a call to firstEntry(), first()
* or findRef().
* \return const Key &
*/
@@ -793,7 +793,7 @@ public:
/**
* \brief Places the hash table iterator at the next entry and returns the associated data value pointer.
*
- * This function must be preceeded by a call to firstEntry(), first()
+ * This function must be preceded by a call to firstEntry(), first()
* or findRef().
* \return T *
*/
@@ -872,7 +872,7 @@ public:
* Automatic deletion is enabled.
* \param uSize The number of hash buckets: does NOT necesairly need to be prime
* \param bCaseSensitive Are the key comparisons case sensitive ?
- * \param bDeepCopyKeys Do we need to mantain deep copies of keys ?
+ * \param bDeepCopyKeys Do we need to maintain deep copies of keys ?
* \return KviPointerHashTable
*/
KviPointerHashTable(unsigned int uSize = 32, bool bCaseSensitive = true, bool bDeepCopyKeys = true)
diff --git a/src/kvilib/core/KviQString.cpp b/src/kvilib/core/KviQString.cpp
index 630704047..f14d3aee5 100644
--- a/src/kvilib/core/KviQString.cpp
+++ b/src/kvilib/core/KviQString.cpp
@@ -1055,7 +1055,7 @@ namespace KviQString
if(!bIsRegExp)
{
- // In wildcard maching mode, QRegExp not only interprets * and ?, but also [ ]
+ // In wildcard matching mode, QRegExp not only interprets * and ?, but also [ ]
// This workaround embeds square brackes in square brackets (ticket #1264)
QChar * pPtr = (QChar*)szExp.constData();
diff --git a/src/kvilib/ext/KviAnimatedPixmapCache.h b/src/kvilib/ext/KviAnimatedPixmapCache.h
index 8e1229c13..ad8c0840c 100644
--- a/src/kvilib/ext/KviAnimatedPixmapCache.h
+++ b/src/kvilib/ext/KviAnimatedPixmapCache.h
@@ -41,7 +41,7 @@ public:
* This subclass represents simple structure
* to store animated frame data: cached pixmap, and next frame delay.
*
- * It provides copyconstructor, wich makes possible to simple
+ * It provides copyconstructor, which makes possible to simple
* assign two containers with this classes.
*
* All data will be duplicated in such case.
diff --git a/src/kvilib/ext/KviConfigurationFile.cpp b/src/kvilib/ext/KviConfigurationFile.cpp
index b0c139c17..2ea967f46 100644
--- a/src/kvilib/ext/KviConfigurationFile.cpp
+++ b/src/kvilib/ext/KviConfigurationFile.cpp
@@ -266,7 +266,7 @@ bool KviConfigurationFile::load()
while(*z)z++;
// run back to the trailing ']'
while((z > begin) && (*z != ']'))z--;
- // if it is not ther just run back to the end of the string
+ // if it is not there just run back to the end of the string
if(*z != ']')while(*z)z++;
#else
// new configs have it always encoded properly
diff --git a/src/kvilib/ext/KviMediaManager.cpp b/src/kvilib/ext/KviMediaManager.cpp
index b128810ba..12128fda4 100644
--- a/src/kvilib/ext/KviMediaManager.cpp
+++ b/src/kvilib/ext/KviMediaManager.cpp
@@ -125,7 +125,7 @@ void KviMediaManager::copyMediaType(KviMediaType * dst,KviMediaType * src)
void KviMediaManager::insertMediaType(KviMediaType * m)
{
KVI_ASSERT(locked());
- int iWildCount = m->szFileMask.occurences('*');
+ int iWildCount = m->szFileMask.occurrences('*');
int iNonWildCount = m->szFileMask.len() - iWildCount;
// The masks with no wildcards go first in the list
@@ -137,7 +137,7 @@ void KviMediaManager::insertMediaType(KviMediaType * m)
if(iWildCount)
{
// the new mask has wildcards... if the current one has none, skip it
- int iWildCountExisting = mt->szFileMask.occurences('*');
+ int iWildCountExisting = mt->szFileMask.occurrences('*');
if(iWildCountExisting)
{
// the one in the list has wildcards too...
diff --git a/src/kvilib/ext/KviOggTheoraEncoder.h b/src/kvilib/ext/KviOggTheoraEncoder.h
index f0c0addd2..e0892f568 100644
--- a/src/kvilib/ext/KviOggTheoraEncoder.h
+++ b/src/kvilib/ext/KviOggTheoraEncoder.h
@@ -86,8 +86,8 @@ private:
size_t y4m_dst_buf_sz; /**< The size of each converted frame buffer */
size_t y4m_dst_buf_read_sz; /**< The amount to read directly into the converted frame buffer */
- size_t y4m_aux_buf_sz; /**< The size of the auxilliary buffer */
- size_t y4m_aux_buf_read_sz; /**< The amount to read into the auxilliary buffer */
+ size_t y4m_aux_buf_sz; /**< The size of the auxiliary buffer */
+ size_t y4m_aux_buf_read_sz; /**< The amount to read into the auxiliary buffer */
ogg_stream_state zo; /**< Take physical pages, weld into a logical stream of irct packets */
ogg_stream_state to; /**< Take physical pages, weld into a logical stream of theora packets */
diff --git a/src/kvilib/irc/KviIrcUserEntry.cpp b/src/kvilib/irc/KviIrcUserEntry.cpp
index 825166d41..e1f0c0e03 100644
--- a/src/kvilib/irc/KviIrcUserEntry.cpp
+++ b/src/kvilib/irc/KviIrcUserEntry.cpp
@@ -57,7 +57,7 @@ void KviIrcUserEntry::setRealName(const QString & szReal)
if((m_szRealName[0].unicode() == KviControlCodes::Color) && (m_szRealName[2].unicode() == KviControlCodes::Reset))
{
// hum.. encoded as hidden color code eh ? publish is somewhere, so others might implement this...
- // for backwards compatibily, 3=bot
+ // for backwards compatibility, 3=bot
if(m_szRealName[1].unicode() & 1 && m_szRealName[1].unicode() & 2)
{
setBot(true); //3
diff --git a/src/kvilib/locale/KviLocale.h b/src/kvilib/locale/KviLocale.h
index 29b48faf3..5201217fd 100644
--- a/src/kvilib/locale/KviLocale.h
+++ b/src/kvilib/locale/KviLocale.h
@@ -162,7 +162,7 @@ public:
* corresponding translation file from the KVIrc locale directory.
* Returns true if the locale was correctly set; i.e. the locale is C or POSIX
* (no translation needed) or the locale is correctly defined and the translation
- * map was sucesfully loaded
+ * map was successfully loaded
* \param szBuffer The buffer where to store the translation full path
* \param szName The name of the translation file
* \param szLocaleDir The directory where the localizations are stored
diff --git a/src/kvilib/net/KviDnsResolverNew.h b/src/kvilib/net/KviDnsResolverNew.h
index ab7db8870..9b6417b71 100644
--- a/src/kvilib/net/KviDnsResolverNew.h
+++ b/src/kvilib/net/KviDnsResolverNew.h
@@ -26,7 +26,7 @@
// This is a nicely working DNS resolver that uses the QHostInfo interface
-// and thus gets rid of all the ugly OS dependancies we have.
+// and thus gets rid of all the ugly OS dependencies we have.
// It should be sufficient to rename this file and use this class
// instead of the old KviDnsResolver.
diff --git a/src/kvilib/system/KviByteOrder.h b/src/kvilib/system/KviByteOrder.h
index 2ad9b7b86..9e9a65274 100644
--- a/src/kvilib/system/KviByteOrder.h
+++ b/src/kvilib/system/KviByteOrder.h
@@ -33,7 +33,7 @@
namespace KviByteOrder
{
/**
- * \brief Swaps the endianess of a kvi_u64_t
+ * \brief Swaps the endianness of a kvi_u64_t
*
* \param i the original value
* \return kvi_u64_t
@@ -52,7 +52,7 @@ namespace KviByteOrder
}
/**
- * \brief Swaps the endianess of a kvi_u32_t
+ * \brief Swaps the endianness of a kvi_u32_t
*
* \param i the original value
* \return kvi_u32_t
@@ -64,7 +64,7 @@ namespace KviByteOrder
}
/**
- * \brief Swaps the endianess of a kvi_u16_t
+ * \brief Swaps the endianness of a kvi_u16_t
*
* \param i the original value
* \return kvi_u16_t
diff --git a/src/kvilib/system/KviThread.cpp b/src/kvilib/system/KviThread.cpp
index bacc0c89e..9d3b7fb9b 100644
--- a/src/kvilib/system/KviThread.cpp
+++ b/src/kvilib/system/KviThread.cpp
@@ -62,7 +62,7 @@ static void kvi_threadIgnoreSigalarm()
// Could not guess more about this stuff...
// Here goes a "blind" hack for that.
- // Update: now we have an explaination too
+ // Update: now we have an explanation too
//
// From: "Andre Stechert" (astechert at email dot com)
// To: pragma at kvirc dot net
@@ -80,7 +80,7 @@ static void kvi_threadIgnoreSigalarm()
// There is no real feedback on this at the moment: if somebody
// experiences the problems please drop me a mail at pragma at kvirc dot net
// and we'll try to look for a better solution.
- // If the explaination is correct then KVIrc could even lock up on those machines
+ // If the explanation is correct then KVIrc could even lock up on those machines
// (never returning from an usleep() call ?)...
struct sigaction ignr_act;
diff --git a/src/kvilib/system/KviTimeUtils.h b/src/kvilib/system/KviTimeUtils.h
index 490a202b4..1f215dc0b 100644
--- a/src/kvilib/system/KviTimeUtils.h
+++ b/src/kvilib/system/KviTimeUtils.h
@@ -82,7 +82,7 @@ protected:
public:
/**
* \brief Returns the number of milliseconds.
- * The amount is caluclated since mark() was last called (and thus marks
+ * The amount is calculated since mark() was last called (and thus marks
* the beginning of a new interval).
* \return unsigned long
*/
diff --git a/src/kvirc/kernel/KviApplication.cpp b/src/kvirc/kernel/KviApplication.cpp
index 1ff71e7f2..4216154c3 100644
--- a/src/kvirc/kernel/KviApplication.cpp
+++ b/src/kvirc/kernel/KviApplication.cpp
@@ -275,7 +275,7 @@ void KviApplication::setup()
KviSSL::globalInit();
#endif
- // Setup our filesystem and initalize locale
+ // Setup our filesystem and initialize locale
loadDirectories();
KviStringConversion::init(m_szGlobalKvircDir,m_szLocalKvircDir);
@@ -668,7 +668,7 @@ void KviApplication::notifierMessage(KviWindow * pWnd, int iIconId, const QStrin
/*
We have different behaviour depending on support enabled at compile time (env)
and options enabled by the user (opt).
- Let's see the scheme to understand which is choosen:
+ Let's see the scheme to understand which is chosen:
1: env: DBus, KDE
opt: a: enabled, enabled -> KDE
@@ -741,7 +741,7 @@ void KviApplication::notifierMessage(KviWindow * pWnd, int iIconId, const QStrin
"Name=KVIrc\n" \
"Comment=Someone sent us a message\n" \
"Action=Popup|Taskbar\n" \
- "Persistant=true\n" \
+ "Persistent=true\n" \
);
KviFileUtils::writeFile(szFileName,szKNotifyConfig);
diff --git a/src/kvirc/kernel/KviIconManager.cpp b/src/kvirc/kernel/KviIconManager.cpp
index ced1c0cc3..6cb06bc3b 100644
--- a/src/kvirc/kernel/KviIconManager.cpp
+++ b/src/kvirc/kernel/KviIconManager.cpp
@@ -228,9 +228,9 @@ static const char * g_szIconNames[KviIconManager::IconCount] =
"gnutella", // 142
"search", // 143
"files", // 144
- "transfer", // 145 //cant see this used anywhere
+ "transfer", // 145 //can't see this used anywhere
"package", // 146
- "retry", // 147 //cant see this used anywhere
+ "retry", // 147 //can't see this used anywhere
"idea", // 148
"colors", // 149
"gui", // 150
@@ -240,7 +240,7 @@ static const char * g_szIconNames[KviIconManager::IconCount] =
"channelnoticecrypted",// 154
"querynotice", // 155
"querynoticecrypted", // 156
- "servnotice", // 157 //cant see this used anywhere
+ "servnotice", // 157 //can't see this used anywhere
"popup", // 158
"prologue", // 159
"epilogue", // 160
@@ -760,9 +760,9 @@ KviIconManager::SmallIcon KviIconManager::iconName(int iIcon)
case 142: return KviIconManager::Gnutella; break;
case 143: return KviIconManager::Search; break;
case 144: return KviIconManager::Files; break;
- case 145: return KviIconManager::Transfer; break; //cant see this used anywhere
+ case 145: return KviIconManager::Transfer; break; //can't see this used anywhere
case 146: return KviIconManager::Package; break;
- case 147: return KviIconManager::Retry; break; //cant see this used anywhere
+ case 147: return KviIconManager::Retry; break; //can't see this used anywhere
case 148: return KviIconManager::Idea; break;
case 149: return KviIconManager::Colors; break;
case 150: return KviIconManager::Gui; break;
@@ -772,7 +772,7 @@ KviIconManager::SmallIcon KviIconManager::iconName(int iIcon)
case 154: return KviIconManager::ChannelNoticeCrypted; break;
case 155: return KviIconManager::QueryNotice; break;
case 156: return KviIconManager::QueryNoticeCrypted; break;
- case 157: return KviIconManager::ServNotice; break; //cant see this used anywhere
+ case 157: return KviIconManager::ServNotice; break; //can't see this used anywhere
case 158: return KviIconManager::Popup; break;
case 159: return KviIconManager::Prologue; break;
case 160: return KviIconManager::Epilogue; break;
diff --git a/src/kvirc/kernel/KviIconManager.h b/src/kvirc/kernel/KviIconManager.h
index a6fff1518..c1b2d9283 100644
--- a/src/kvirc/kernel/KviIconManager.h
+++ b/src/kvirc/kernel/KviIconManager.h
@@ -310,9 +310,9 @@ public:
Gnutella = 142,
Search = 143,
Files = 144,
- Transfer = 145, //cant see this used anywhere
+ Transfer = 145, //can't see this used anywhere
Package = 146,
- Retry = 147, //cant see this used anywhere
+ Retry = 147, //can't see this used anywhere
Idea = 148,
Colors = 149,
Gui = 150,
@@ -322,7 +322,7 @@ public:
ChannelNoticeCrypted = 154,
QueryNotice = 155,
QueryNoticeCrypted = 156,
- ServNotice = 157, //cant see this used anywhere
+ ServNotice = 157, //can't see this used anywhere
Popup = 158,
Prologue = 159,
Epilogue = 160,
diff --git a/src/kvirc/kernel/KviIrcConnection.h b/src/kvirc/kernel/KviIrcConnection.h
index f5b68ba1e..b43c11f04 100644
--- a/src/kvirc/kernel/KviIrcConnection.h
+++ b/src/kvirc/kernel/KviIrcConnection.h
@@ -117,7 +117,7 @@ protected:
* takes the ownership.
* \param pContext The KviIrcContext we're attacched to
* \param pTarget The server data
- * \param pIdentity User information to use in ths connection
+ * \param pIdentity User information to use in this connection
* \return KviIrcConnection
*/
KviIrcConnection(KviIrcContext * pContext,KviIrcConnectionTarget * pTarget,KviUserIdentity * pIdentity);
@@ -605,7 +605,7 @@ public:
* correctly connected link causes the link to actually disconnect (or
* rather "discover" the fact that it's disconnected at OS level).
* \param pcFmt The format string to be first sprintf'ed with the variadic params and then sent
- * \param ... The variadic arguments (see man sprintf for an explaination)
+ * \param ... The variadic arguments (see man sprintf for an explanation)
* \return bool
*
* FIXME: change name to sendFormattedData() ?
@@ -672,8 +672,8 @@ public:
* \brief Sets the global encoding for this connection.
*
* This is a default value and can be overridden by specific windows.
- * This is tipically called upon a successfull CODEPAGE change (numerical 222)
- * reponse from a server; from now on, the server will translate (encode)
+ * This is tipically called upon a successful CODEPAGE change (numerical 222)
+ * response from a server; from now on, the server will translate (encode)
* everything (including IDN hostnames, channel names, messages) using this
* encoding. So we expect this encoding to be the new default for the server
* (connection), the console, each other channel and query.
diff --git a/src/kvirc/kernel/KviIrcConnectionServerInfo.h b/src/kvirc/kernel/KviIrcConnectionServerInfo.h
index 4ac7c45cc..cc6d0dcae 100644
--- a/src/kvirc/kernel/KviIrcConnectionServerInfo.h
+++ b/src/kvirc/kernel/KviIrcConnectionServerInfo.h
@@ -266,7 +266,7 @@ public:
class KVIRC_API KviHyperionIrcServerInfo : public KviBasicIrcServerInfo
{
- // legacy freenode : no longer mantained
+ // legacy freenode : no longer maintained
public:
KviHyperionIrcServerInfo(KviIrcConnectionServerInfo * pParent = 0, const QString & version = KviQString::Empty)
:KviBasicIrcServerInfo(pParent, version) {;};
diff --git a/src/kvirc/kernel/KviIrcConnectionStateData.h b/src/kvirc/kernel/KviIrcConnectionStateData.h
index e0052ae53..17055a8f9 100644
--- a/src/kvirc/kernel/KviIrcConnectionStateData.h
+++ b/src/kvirc/kernel/KviIrcConnectionStateData.h
@@ -31,7 +31,7 @@
#include <QStringList>
//
-// This class is used as container for miscelaneous connection state variables
+// This class is used as container for miscellaneous connection state variables
// that do not have a class for their own.
// If you need to add some "minor" variable to the connection state then
// this is the right place for it.
diff --git a/src/kvirc/kernel/KviIrcUrl.cpp b/src/kvirc/kernel/KviIrcUrl.cpp
index 7380e3b64..6faedb59f 100644
--- a/src/kvirc/kernel/KviIrcUrl.cpp
+++ b/src/kvirc/kernel/KviIrcUrl.cpp
@@ -194,7 +194,7 @@ void KviIrcUrl::makeJoinCmd(const QStringList& chans, QString& szJoinCommand)
int KviIrcUrl::run(const QString& text, int contextSpec, KviConsoleWindow* pConsole)
{
- // first, sanity chek the url
+ // first, sanity check the url
QString cmdBuffer;
QString szJoinCommand;
KviIrcUrlParts parts;
diff --git a/src/kvirc/kernel/KviOptions.h b/src/kvirc/kernel/KviOptions.h
index f28ab57ac..f52795a6b 100644
--- a/src/kvirc/kernel/KviOptions.h
+++ b/src/kvirc/kernel/KviOptions.h
@@ -781,7 +781,7 @@ extern KVIRC_API KviStringListOption g_stringlistOptionsTable[KVI_NUM_STRINGLIST
#define KviOption_resetMask (~(KviOption_sectMask | KviOption_groupMask))
- //for file pathes
+ //for file paths
#define KviOption_encodePath (1 << 25)
#endif
diff --git a/src/kvirc/kvs/KviKvsArray.cpp b/src/kvirc/kvs/KviKvsArray.cpp
index 9637dfe62..fc71ac5ee 100644
--- a/src/kvirc/kvs/KviKvsArray.cpp
+++ b/src/kvirc/kvs/KviKvsArray.cpp
@@ -145,7 +145,7 @@ void KviKvsArray::findNewSize()
if((m_uAllocSize - m_uSize) > KVI_KVS_ARRAY_ALLOC_CHUNK)
{
m_uAllocSize = m_uSize;
- // m_pData is non-zero here since was m_uSize > 0 initally
+ // m_pData is non-zero here since was m_uSize > 0 initially
if(m_uSize > 0)
{
m_pData = (KviKvsVariant **)KviMemory::reallocate(m_pData,(sizeof(KviKvsVariant *)) * m_uAllocSize);
diff --git a/src/kvirc/kvs/KviKvsCoreCallbackCommands.cpp b/src/kvirc/kvs/KviKvsCoreCallbackCommands.cpp
index 9cc5d4c4d..7d894ac6e 100644
--- a/src/kvirc/kvs/KviKvsCoreCallbackCommands.cpp
+++ b/src/kvirc/kvs/KviKvsCoreCallbackCommands.cpp
@@ -354,7 +354,7 @@ namespace KviKvsCoreCallbackCommands
empty with the exception of $0.[br]
If the connection gets interrupted before all the information have been received,
the <callback command> will never be triggered.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
@examples:
[example]
awhois(pragma){ echo $0-; }
diff --git a/src/kvirc/kvs/KviKvsCoreFunctions_gl.cpp b/src/kvirc/kvs/KviKvsCoreFunctions_gl.cpp
index 71af2a79b..6c892942f 100644
--- a/src/kvirc/kvs/KviKvsCoreFunctions_gl.cpp
+++ b/src/kvirc/kvs/KviKvsCoreFunctions_gl.cpp
@@ -63,7 +63,7 @@ namespace KviKvsCoreFunctions
The gender is known if [fnc]$isWellKnown[/fnc] returns 1.[br]
The gender is generally known if the user is on a channel with you
or has an open query with you.[br]
- Detailed explaination:[br]
+ Detailed explanation:[br]
KVIrc has an internal database of users that are currently
visible by *this client*: this includes users on open channels
and queries.[br] The other IRC users are [b]not[/b] in the database:
@@ -556,7 +556,7 @@ KVSCF(gender)
This info is known if [fnc]$isWellKnown[/fnc] returns 1.[br]
This info is generally known if the user is on a channel with you
or has an open query with you.[br]
- Detailed explaination:[br]
+ Detailed explanation:[br]
KVIrc has an internal database of users that are currently
visible by *this client*: this includes users on open channels
and queries.[br] The other IRC users are [b]not[/b] in the database:
diff --git a/src/kvirc/kvs/KviKvsCoreFunctions_mr.cpp b/src/kvirc/kvs/KviKvsCoreFunctions_mr.cpp
index fed40b772..1a1b945bb 100644
--- a/src/kvirc/kvs/KviKvsCoreFunctions_mr.cpp
+++ b/src/kvirc/kvs/KviKvsCoreFunctions_mr.cpp
@@ -557,7 +557,7 @@ namespace KviKvsCoreFunctions
with the same seed value. If [cmd]srand[/cmd] has not been called
$rand is automatically seeded with value of 1.
If no <max> is specified, this function returns an integer between
- 0 and RAND_MAX that is system dependant.
+ 0 and RAND_MAX that is system dependent.
@examples:
[example]
[/example]
@@ -646,7 +646,7 @@ namespace KviKvsCoreFunctions
The realname is known if [fnc]$isWellKnown[/fnc] returns 1.[br]
The realname is generally known if the user is on a channel with you
or has an open query with you.[br]
- Detailed explaination:[br]
+ Detailed explanation:[br]
KVIrc has an internal database of users that are currently
visible by *this client*: this includes users on open channels
and queries.[br] The other IRC users are [b]not[/b] in the database:
diff --git a/src/kvirc/kvs/KviKvsCoreFunctions_sz.cpp b/src/kvirc/kvs/KviKvsCoreFunctions_sz.cpp
index 6d830c616..ee9834aec 100644
--- a/src/kvirc/kvs/KviKvsCoreFunctions_sz.cpp
+++ b/src/kvirc/kvs/KviKvsCoreFunctions_sz.cpp
@@ -995,7 +995,7 @@ namespace KviKvsCoreFunctions
The username is known if [fnc]$isWellKnown[/fnc] returns 1.[br]
The username is generally known if the user is on a channel with you
or has an open query with you.[br]
- Detailed explaination:[br]
+ Detailed explanation:[br]
KVIrc has an internal database of users that are currently
visible by *this client*: this includes users on open channels
and queries.[br] The other IRC users are [b]not[/b] in the database:
diff --git a/src/kvirc/kvs/KviKvsCoreSimpleCommands_af.cpp b/src/kvirc/kvs/KviKvsCoreSimpleCommands_af.cpp
index 7d696cf1a..f3573b935 100644
--- a/src/kvirc/kvs/KviKvsCoreSimpleCommands_af.cpp
+++ b/src/kvirc/kvs/KviKvsCoreSimpleCommands_af.cpp
@@ -102,7 +102,7 @@ namespace KviKvsCoreSimpleCommands
When you use this command, other people will know that you are
away from the keyboard, and they will know why you're not here.[br]
To return from being away you must use [cmd]back[/cmd].[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
If no away reason is specified, the behaviour of this command depends from the value
of the option boolUseAwayMessage: if enabled, user will be set away using the default
away message (or "Away from keyboard" if no default away message is set);
@@ -199,7 +199,7 @@ namespace KviKvsCoreSimpleCommands
current [b]IRC context[/b].[br] This command is "server based";
this means that the effects will be visible only after the
server has acknowledged the change.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
@examples:
[example]
back
@@ -251,7 +251,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of +b flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
ban Maxim,Gizmo!*@*,*!root@*
@@ -305,7 +305,7 @@ namespace KviKvsCoreSimpleCommands
If the -s switch is specified the bell becomes synchronous:
KVIrc waits the bell to complete before continuing.[br]
The precision of the bell pitch, duration and
- volume is strongly dependant on the system and the underlying hardware.[br][br]
+ volume is strongly dependent on the system and the underlying hardware.[br][br]
On Windows, the bell is always synchronous and it is not
event granted that the bell will be a bell at all... you might
get the system default sound instead...
@@ -509,7 +509,7 @@ namespace KviKvsCoreSimpleCommands
The <command> may be one of LS,REQ,LIST and ACK as per CAP specification (Google for draft-mitchell-irc-capabilities-02).
The <parameters> string usually contains a list of capabilities to be activated or deactivated (deactivation is triggered
by prepending a - prefix to the capability name.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc] and actually works only on servers
+ This command is [doc:connection_dependant_commands]connection dependent[/doc] and actually works only on servers
that implement the CAP capability.
@examples:
[example]
@@ -565,7 +565,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of +a flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
chanadmin Pragma,Crocodile
@@ -597,7 +597,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of +q flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
chanowner Pragma,Crocodile
@@ -653,7 +653,7 @@ namespace KviKvsCoreSimpleCommands
If <ctcp_data> is the single string "ping" then a trailing time string argument
is added in order to determine the round trip time when the ping reply comes back.
To override this behaviour simply specify your own time string parameter.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
@examples:
[example]
ctcp Pragma VERSION
@@ -748,7 +748,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of -a flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
dechanadmin Pragma,Crocodile
@@ -780,7 +780,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of -q flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
dechanowner Pragma,Crocodile
@@ -812,7 +812,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of -h flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
dehalfop Pragma,Crocodile
@@ -972,7 +972,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of -o flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
deop Pragma,Crocodile
@@ -1004,7 +1004,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of -u flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
deuserop Pragma,Crocodile
@@ -1036,7 +1036,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of -v flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
devoice Pragma,Crocodile
diff --git a/src/kvirc/kvs/KviKvsCoreSimpleCommands_gl.cpp b/src/kvirc/kvs/KviKvsCoreSimpleCommands_gl.cpp
index c0c610167..3a41181ef 100644
--- a/src/kvirc/kvs/KviKvsCoreSimpleCommands_gl.cpp
+++ b/src/kvirc/kvs/KviKvsCoreSimpleCommands_gl.cpp
@@ -50,7 +50,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of +h flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
halfop Pragma,Crocodile
@@ -388,7 +388,7 @@ namespace KviKvsCoreSimpleCommands
optional keys in the [key list].[br]
This command is "server based"; you will see its results only
after the server acknowledges it.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
@examples:
[example]
join #kvirc
@@ -459,7 +459,7 @@ namespace KviKvsCoreSimpleCommands
@description:
Kicks the specified <user> from the current channel.[br]
This command is a simple wrapper over the IRC KICK command.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
kick Pragma Go coding in Pascal!
diff --git a/src/kvirc/kvs/KviKvsCoreSimpleCommands_mr.cpp b/src/kvirc/kvs/KviKvsCoreSimpleCommands_mr.cpp
index 5adb4ee33..c392a83ff 100644
--- a/src/kvirc/kvs/KviKvsCoreSimpleCommands_mr.cpp
+++ b/src/kvirc/kvs/KviKvsCoreSimpleCommands_mr.cpp
@@ -140,7 +140,7 @@ namespace KviKvsCoreSimpleCommands
Sends a MODE IRC message to the server of the current IRC context.[br]
The parameters are not modified in any way by KVIrc: so
you should use the RFC1459 syntax.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
mode #kvirc +oo-b Pragma Buti *!*root@*
@@ -208,7 +208,7 @@ namespace KviKvsCoreSimpleCommands
IRC protocol (see RFC1459).
This is really similar to [cmd]privmsg[/cmd] but also outputs the
message locally (unless the [-q] switch is used).[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
*/
// Internally aliased to privmsg
@@ -229,7 +229,7 @@ namespace KviKvsCoreSimpleCommands
current [b]IRC context[/b].[br] This command is "server based";
this means that the effects will be visible only after the
server has acknowledged the change.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
@examples:
[example]
nick Pragma
@@ -276,7 +276,7 @@ namespace KviKvsCoreSimpleCommands
<target> may be any NOTICE target allowed by the underlying
IRC protocol (see RFC1459).
If the [-q] switch is specified, no output is printed.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
@examples:
[example]
notice Pragma Hello!
@@ -330,7 +330,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of +o flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
op Pragma,Crocodile
@@ -764,7 +764,7 @@ namespace KviKvsCoreSimpleCommands
after the part (the channels become dead channels).[br]
If the -s switch is specified then the part message is not shown
in the channel window.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
This command is equivalent to [cmd]leave[/cmd]
@examples:
[example]
@@ -958,7 +958,7 @@ namespace KviKvsCoreSimpleCommands
IRC protocol (see RFC1459).
This command is really similar to [cmd]msg[/cmd] but it does not
output the message locally.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
This command is equivalent to [cmd]msg[/cmd]
@examples:
[example]
@@ -1024,7 +1024,7 @@ namespace KviKvsCoreSimpleCommands
query window just as it would have been written in the query itself.
If a query with one of the specified targets already exists,
it is simply focused and the [text] is sent to the target.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
Normally the new query windows opened with this command are created and immediately shown.
If the -i switch is specified then the windows are created either as minimized or as visible
depending on the global visibility setting specified by the boolCreateIncomingQueriesAsMinimized option.
@@ -1218,7 +1218,7 @@ namespace KviKvsCoreSimpleCommands
@description:
Sends a RAW data string to the server of the current [b]IRC context[/b].[br]
If the -q switch (quiet) is specified, no output is printed.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
This command is equivalent to [cmd]quote[/cmd].
@examples:
[example]
diff --git a/src/kvirc/kvs/KviKvsCoreSimpleCommands_sz.cpp b/src/kvirc/kvs/KviKvsCoreSimpleCommands_sz.cpp
index f3e3cb20e..39572a0b1 100644
--- a/src/kvirc/kvs/KviKvsCoreSimpleCommands_sz.cpp
+++ b/src/kvirc/kvs/KviKvsCoreSimpleCommands_sz.cpp
@@ -505,7 +505,7 @@ namespace KviKvsCoreSimpleCommands
@description:
Sends a message to a service in a form similar to [cmd]privmsg[/cmd].[br]
<target> must be a service(see RFC2812).
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
@examples:
[example]
squery Alis LIST * -min 100
@@ -614,7 +614,7 @@ namespace KviKvsCoreSimpleCommands
@description:
Requests the stats information from the specified server or the current server if no [target server] is specified.[br]
The query parameter is usually a letter indicating the type of the query requested: some query letters
- are defined by [doc]rfc2812[/doc] and some others are server implementation dependant.[br]
+ are defined by [doc]rfc2812[/doc] and some others are server implementation dependent.[br]
This command is an [doc:rfc2812wrappers]RFC2812 command wrapper[/doc]; see that document for more information.[br]
*/
// RFC2812 wrapper
@@ -654,7 +654,7 @@ namespace KviKvsCoreSimpleCommands
If no topic is specified, the current channel topic will be returned.[br]
This command is "server based"; you will see its results only
after the server acknowledges it.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
topic #kvirc KVIrc 3.4.0 has been released!
@@ -842,7 +842,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of -b flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
# Unban people on the current channel (say #kvirc)
@@ -883,7 +883,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of +u flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
userop Pragma,Crocodile
@@ -933,7 +933,7 @@ namespace KviKvsCoreSimpleCommands
This command works only if executed in a channel window.
The command is translated to a set of MODE messages containing
a variable number of +v flags.
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
voice Pragma,Crocodile
@@ -1002,7 +1002,7 @@ namespace KviKvsCoreSimpleCommands
Look for the extended WHOX syntax on your favorite search engine.[br]
If no parameter is specified at all, it requests a WHO information about the current
channel.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
[comment]# Lists users on #kvirc[/comment]
@@ -1065,7 +1065,7 @@ namespace KviKvsCoreSimpleCommands
whois <nickname> <nickname>[br]
This will requests information about the user <nickname> to the server that he is currently
connected to; returning the idle time among the other common information.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
[comment]# Query info about Pragma[/comment]
@@ -1109,7 +1109,7 @@ namespace KviKvsCoreSimpleCommands
@description:
Requests information about an IRC user specified by <nickname>.[br]
Whowas requests "history" records. See [doc:rfc2812]RFC2812[/doc] for more info.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].
@examples:
[example]
[comment]# Query past info about Pragma[/comment]
diff --git a/src/kvirc/kvs/KviKvsUserAction.h b/src/kvirc/kvs/KviKvsUserAction.h
index 4ec8a2842..bf8558c91 100644
--- a/src/kvirc/kvs/KviKvsUserAction.h
+++ b/src/kvirc/kvs/KviKvsUserAction.h
@@ -53,7 +53,7 @@ public:
// Static allocator function.
// This MUST be used by the modules to allocate action structures
// instead of the new operator.
- // See KviHeapObject.cpp for an explaination.
+ // See KviHeapObject.cpp for an explanation.
static KviKvsUserAction * createInstance(
QObject * pParent,
const QString & szName,
diff --git a/src/kvirc/kvs/event/KviKvsEventHandler.h b/src/kvirc/kvs/event/KviKvsEventHandler.h
index dd8c62f70..e9e0a9d49 100644
--- a/src/kvirc/kvs/event/KviKvsEventHandler.h
+++ b/src/kvirc/kvs/event/KviKvsEventHandler.h
@@ -65,7 +65,7 @@ public:
// Static allocator function.
// This MUST be used by the modules to allocate event structures
// instead of the new operator.
- // See KviHeapObject.cpp for an explaination.
+ // See KviHeapObject.cpp for an explanation.
static KviKvsScriptEventHandler * createInstance(const QString &szHandlerName,const QString &szContextName,const QString &szCode,bool bEnabled = true);
};
diff --git a/src/kvirc/kvs/parser/KviKvsParser.cpp b/src/kvirc/kvs/parser/KviKvsParser.cpp
index b14a31940..1b2fcf6f9 100644
--- a/src/kvirc/kvs/parser/KviKvsParser.cpp
+++ b/src/kvirc/kvs/parser/KviKvsParser.cpp
@@ -487,7 +487,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const QChar * pBuffer
[/example]
The above example will treat the ';' as a part of the parameters and print it.[br]
In some languages the action of [i]escaping[/i] a character is called [i]quoting[/i].
- Altough there is some confusion in this term, the meaning is to either use quotes
+ Although there is some confusion in this term, the meaning is to either use quotes
or to use the escape character to remove special meaning from some characters.
By quoting the spaces you can include them in a parameter, by escaping the quotes
you can include them in a command.
@@ -1089,11 +1089,11 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const QChar * pBuffer
@type:
language
@title:
- Connection dependant commands
+ Connection dependent commands
@keyterms:
- IRC context, connection dependant commands
+ IRC context, connection dependent commands
@body:
- Many KVIrc commands are connection dependant:
+ Many KVIrc commands are connection dependent:
you need an IRC connection to successfully execute them;
usually because some data needs to be sent to the server.
This includes commands like [cmd]whois[/cmd],[cmd]raw[/cmd],[cmd]query[/cmd],
@@ -1742,7 +1742,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const QChar * pBuffer
[/tr]
[tr]
[td]<simple command>[/td]
- [td][<module name>'.']<command name>[<switch list>]{<space>}<command dependant part>[/td]
+ [td][<module name>'.']<command name>[<switch list>]{<space>}<command dependent part>[/td]
[/tr]
[tr]
[td]<lvalue command>[/td]
@@ -1809,7 +1809,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const QChar * pBuffer
[td]Any ascii character except <space> and <command terminator>[/td]
[/tr]
[tr]
- [td]<command dependant part>[/td]
+ [td]<command dependent part>[/td]
[td][b]Production in each command help page[/b][/td]
[/tr]
[/table]
@@ -2011,7 +2011,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const QChar * pBuffer
KVIrc allocates a pointer for each item in the array. The pointer is
empty when the item is unset and points to an additional block
of memory when the item is set. The size of a pointer is platform
- dependant: on the platforms supported by KVIrc it's either 32 or 64 bit.
+ dependent: on the platforms supported by KVIrc it's either 32 or 64 bit.
The size of the additional block depends both on the platform
and on the contents of the item... it's average value may
be around 16 bytes. The array size is determined by the last SET element index.
diff --git a/src/kvirc/kvs/tree/KviKvsTreeNodeCompositeData.cpp b/src/kvirc/kvs/tree/KviKvsTreeNodeCompositeData.cpp
index 1a71c4f17..aa39334b9 100644
--- a/src/kvirc/kvs/tree/KviKvsTreeNodeCompositeData.cpp
+++ b/src/kvirc/kvs/tree/KviKvsTreeNodeCompositeData.cpp
@@ -53,7 +53,7 @@ bool KviKvsTreeNodeCompositeData::evaluateReadOnly(KviKvsRunTimeContext * c,KviK
KviKvsVariant res;
- // we need to use an iterator to accomodate recursion
+ // we need to use an iterator to accommodate recursion
KviPointerListIterator<KviKvsTreeNodeData> it(*m_pSubData);
while(KviKvsTreeNodeData * d = it.current())
diff --git a/src/kvirc/kvs/tree/KviKvsTreeNodeDataList.cpp b/src/kvirc/kvs/tree/KviKvsTreeNodeDataList.cpp
index 8a3e4d487..c65e511bc 100644
--- a/src/kvirc/kvs/tree/KviKvsTreeNodeDataList.cpp
+++ b/src/kvirc/kvs/tree/KviKvsTreeNodeDataList.cpp
@@ -78,7 +78,7 @@ bool KviKvsTreeNodeDataList::evaluate(KviKvsRunTimeContext * c,KviKvsVariantList
{
pBuffer->clear();
- // we use an iterator to accomodate recursion
+ // we use an iterator to accommodate recursion
KviPointerListIterator<KviKvsTreeNodeData> it(*m_pDataList);
while(KviKvsTreeNodeData * t = it.current())
{
diff --git a/src/kvirc/kvs/tree/KviKvsTreeNodeInstructionBlock.cpp b/src/kvirc/kvs/tree/KviKvsTreeNodeInstructionBlock.cpp
index 78cf6bbd3..8881013cf 100644
--- a/src/kvirc/kvs/tree/KviKvsTreeNodeInstructionBlock.cpp
+++ b/src/kvirc/kvs/tree/KviKvsTreeNodeInstructionBlock.cpp
@@ -74,7 +74,7 @@ void KviKvsTreeNodeInstructionBlock::addInstruction(KviKvsTreeNodeInstruction *
bool KviKvsTreeNodeInstructionBlock::execute(KviKvsRunTimeContext * c)
{
- // to accomodate recursion we need to use an iterator here
+ // to accommodate recursion we need to use an iterator here
KviPointerListIterator<KviKvsTreeNodeInstruction> it(*m_pInstructionList);
while(KviKvsTreeNodeInstruction * i = it.current())
{
diff --git a/src/kvirc/module/KviModule.cpp b/src/kvirc/module/KviModule.cpp
index 4cff7e571..4be6bba40 100644
--- a/src/kvirc/module/KviModule.cpp
+++ b/src/kvirc/module/KviModule.cpp
@@ -106,7 +106,7 @@ extern KVIRC_API KviModuleExtensionManager * g_pModuleExtensionManager;
After the command execution KVIrc waits some user defined interval of time
(typically 2-3 minutes) and then check the module state: if the module
has not been referenced again, it is unloaded, otherwise it is kept in memory
- for another period of time. To prevent accidentaly unloading a module
+ for another period of time. To prevent accidentally unloading a module
that has some windows or dialogs open, a module can lock itself in memory.
For example, the 'help' module lock itself when a help browser window is open
and unlocks itself when the last help browser window is closed.[br]
diff --git a/src/kvirc/sparser/KviIrcServerParser_ctcp.cpp b/src/kvirc/sparser/KviIrcServerParser_ctcp.cpp
index a55e661dc..dba7cbbb7 100644
--- a/src/kvirc/sparser/KviIrcServerParser_ctcp.cpp
+++ b/src/kvirc/sparser/KviIrcServerParser_ctcp.cpp
@@ -369,7 +369,7 @@ extern KVIRC_API KviCtcpPageDialog * g_pCtcpPageDialog;
non-standard private message syntax. This convention should be dropped.[br]
[big]DCC[/big][br]
- [b]Syntax: <0x01>DCC <type> <type dependant parameters><0x01>[/b][br]
+ [b]Syntax: <0x01>DCC <type> <type dependent parameters><0x01>[/b][br]
The DCC tag is used to initiate a Direct Client Connection.
The known DCC types are:[br]
CHAT[br]
diff --git a/src/kvirc/sparser/KviIrcServerParser_numericHandlers.cpp b/src/kvirc/sparser/KviIrcServerParser_numericHandlers.cpp
index 3a2c7d5a8..e4784bcb3 100644
--- a/src/kvirc/sparser/KviIrcServerParser_numericHandlers.cpp
+++ b/src/kvirc/sparser/KviIrcServerParser_numericHandlers.cpp
@@ -144,9 +144,9 @@ void KviIrcServerParser::parseNumeric004(KviIrcMessage *msg)
version.append(msg->safeParam(3));
}
- if((umodes.occurences('o') != 1) || (chanmodes.occurences('o') != 1) ||
- (chanmodes.occurences('b') != 1) || (chanmodes.occurences('v') != 1) ||
- (chanmodes.occurences('t') != 1) || (chanmodes.occurences('n') != 1) ||
+ if((umodes.occurrences('o') != 1) || (chanmodes.occurrences('o') != 1) ||
+ (chanmodes.occurrences('b') != 1) || (chanmodes.occurrences('v') != 1) ||
+ (chanmodes.occurrences('t') != 1) || (chanmodes.occurrences('n') != 1) ||
(chanmodes.contains('.')) || (chanmodes.contains('-')) || (chanmodes.contains('(')))
{
if(!_OUTPUT_QUIET)
@@ -1294,7 +1294,7 @@ void KviIrcServerParser::parseNumericYouHaveCallerID(KviIrcMessage * msg)
pOut = (KviWindow *)(msg->console());
// Because some IRCds return the host jammed together with the nick in an awkward way, making one
- // less paramter returned in RPL_UMODEGMSG.
+ // less parameter returned in RPL_UMODEGMSG.
if(szRemoteHost == szText)
pOut->output(KVI_OUT_HELP,"%Q %Q",&szRemoteUser,&szText);
else
diff --git a/src/kvirc/ui/KviChannelWindow.h b/src/kvirc/ui/KviChannelWindow.h
index e8eefaeb2..e296c6259 100644
--- a/src/kvirc/ui/KviChannelWindow.h
+++ b/src/kvirc/ui/KviChannelWindow.h
@@ -386,7 +386,7 @@ public:
bool hasAllNames(){ return (m_iStateFlags & HaveAllNames); };
/**
- * \brief Sets the existance of all names
+ * \brief Sets the existence of all names
* \return void
*/
void setHasAllNames(){ m_iStateFlags |= HaveAllNames; checkChannelSync(); };
@@ -404,7 +404,7 @@ public:
bool hasWhoList(){ return (m_iStateFlags & HaveWhoList); };
/**
- * \brief Sets the existance of the WHO list
+ * \brief Sets the existence of the WHO list
* \return void
*/
void setHasWhoList(){ m_iStateFlags |= HaveWhoList; checkChannelSync(); };
diff --git a/src/kvirc/ui/KviIpEditor.cpp b/src/kvirc/ui/KviIpEditor.cpp
index 525d7b15e..259596385 100644
--- a/src/kvirc/ui/KviIpEditor.cpp
+++ b/src/kvirc/ui/KviIpEditor.cpp
@@ -109,7 +109,7 @@ void KviIpEditor::clear()
bool KviIpEditor::setAddress(const QString &ipAddr)
{
- // FIXME We could check if the addres
+ // FIXME We could check if the address
// is valid before effectively setting the fields
clear();
diff --git a/src/kvirc/ui/KviIrcView.cpp b/src/kvirc/ui/KviIrcView.cpp
index ca02d5c3f..b5ff62ac1 100644
--- a/src/kvirc/ui/KviIrcView.cpp
+++ b/src/kvirc/ui/KviIrcView.cpp
@@ -1012,7 +1012,7 @@ void KviIrcView::paintEvent(QPaintEvent *p)
/*
* Profane description: this is ircview's most important function. It takes a lot of cpu cycles to complete, so we want to be sure
- * it's well optimized. First, we want to skip this method everytime it's useless: it we're too short or we're covered by other windows.
+ * it's well optimized. First, we want to skip this method every time it's useless: it we're too short or we're covered by other windows.
*/
if(!isVisible())
diff --git a/src/kvirc/ui/KviMainWindow.cpp b/src/kvirc/ui/KviMainWindow.cpp
index 20ea1be1b..6f6421193 100644
--- a/src/kvirc/ui/KviMainWindow.cpp
+++ b/src/kvirc/ui/KviMainWindow.cpp
@@ -139,7 +139,7 @@ KviMainWindow::KviMainWindow()
m_pStatusBar = new KviStatusBar(this);
setStatusBar(m_pStatusBar);
// torque: moved out of status bar constructor
- // because module init functions exectued in load()
+ // because module init functions executed in load()
// couldn't access the status bar via g_pMainWindow->mainStatusBar()
// (assignment of m_pStatusBar happened after load() and
// the init function)
diff --git a/src/kvirc/ui/KviStatusBar.h b/src/kvirc/ui/KviStatusBar.h
index 9deed493b..c71a28b04 100644
--- a/src/kvirc/ui/KviStatusBar.h
+++ b/src/kvirc/ui/KviStatusBar.h
@@ -149,7 +149,7 @@ public:
/**
* \brief Returns true if the applet exists, false otherwise
- * \param pApplet The pointer to the applet to check existance
+ * \param pApplet The pointer to the applet to check existence
* \return bool
*/
bool appletExists(KviStatusBarApplet * pApplet);
diff --git a/src/modules/about/ENTRIES b/src/modules/about/ENTRIES
index ad5822a81..362f94833 100644
--- a/src/modules/about/ENTRIES
+++ b/src/modules/about/ENTRIES
@@ -144,7 +144,7 @@ SECTION: Services
NAME: Jan Wagner
NICK: Istari
NICK: spion
-ROLE: Webmaster, bughunter, snapshot mantainer
+ROLE: Webmaster, bughunter, snapshot maintainer
ROLE: support gay^Wguy :o) and the man that gives
ROLE: you KVIrc through IPv6.
@@ -342,6 +342,6 @@ TEXT: I don't know what I want, but I know how to get it.
NAME: Max Brazhnikov
NICK: makc
MAIL: makc at FreeBSD dot org
-ROLE: FreeBSD Port mantainer
-TEXT: Ports commiter
+ROLE: FreeBSD Port maintainer
+TEXT: Ports committer
diff --git a/src/modules/about/abouttext.inc b/src/modules/about/abouttext.inc
index 695a7e3af..e788a667b 100644
--- a/src/modules/about/abouttext.inc
+++ b/src/modules/about/abouttext.inc
@@ -446,7 +446,7 @@ static const char * g_szAboutText = "" \
"spion" \
")</font></td></tr>" \
"<tr><td align=\"center\"><font color=\"#303030\">" \
-"Webmaster, bughunter, snapshot mantainer" \
+"Webmaster, bughunter, snapshot maintainer" \
"<br>" \
"support gay^Wguy :o) and the man that gives" \
"<br>" \
@@ -1006,21 +1006,21 @@ static const char * g_szAboutText = "" \
"</table><br><br>" \
"<table width=\"100%\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\">" \
"<tr><td align=\"center\">" \
-"<font color=\"#000000\" size=\"+2\"><b>Chris Petrik</b></font>" \
+"<font color=\"#000000\" size=\"+2\"><b>Max Brazhnikov</b></font>" \
"</td></tr>" \
"<tr><td align=\"center\"><font color=\"#800020\" size=\"+2\"> (" \
-"cpet" \
+"makc" \
")</font></td></tr>" \
"<tr><td align=\"center\"><font color=\"#0000FF\" size=\"+1\">" \
"[" \
-"chris at officialunix dot com" \
+"makc at FreeBSD dot org" \
"]" \
"</font></td></tr>" \
"<tr><td align=\"center\"><font color=\"#303030\">" \
-"FreeBSD Port mantainer" \
+"FreeBSD Port maintainer" \
"</font></td></tr>" \
"<tr><td align=\"center\"><font color=\"#606060\"><i>" \
-"\"FreeBSD Gimp.\"" \
+"\"Ports committer\"" \
"</i></font></td></tr>" \
"</table><br><br>" \
"<br>" \
diff --git a/src/modules/about/mkabouttext.pl b/src/modules/about/mkabouttext.pl
index a5c0da76f..a5c0da76f 100644..100755
--- a/src/modules/about/mkabouttext.pl
+++ b/src/modules/about/mkabouttext.pl
diff --git a/src/modules/avatar/libkviavatar.cpp b/src/modules/avatar/libkviavatar.cpp
index 692834be3..5fd90aa7b 100644
--- a/src/modules/avatar/libkviavatar.cpp
+++ b/src/modules/avatar/libkviavatar.cpp
@@ -345,7 +345,7 @@ static bool avatar_kvs_cmd_unset(KviKvsModuleCommandCall * c)
on the target side.[br]
[b]Warning:[/b] The implementation of the avatar protocol is actually
restricted to KVIrc clients only. In the future other clients may implement it.[br]
- This command is [doc:connection_dependant_commands]connection dependant[/doc].[br]
+ This command is [doc:connection_dependant_commands]connection dependent[/doc].[br]
@examples:
[example]
[comment]# Notify your current avatar to Pragma[/comment]
diff --git a/src/modules/classeditor/ClassEditorWindow.h b/src/modules/classeditor/ClassEditorWindow.h
index df7d15bd3..b24ef1271 100644
--- a/src/modules/classeditor/ClassEditorWindow.h
+++ b/src/modules/classeditor/ClassEditorWindow.h
@@ -594,7 +594,7 @@ public:
* \param szClassName The name of the class
* \param szFunctionName The name of the function
* \param szReminder The parameters of the function
- * \param bIsInternal Whether the funtion is set as internal
+ * \param bIsInternal Whether the function is set as internal
* \param bRenameMode Whether the dialog is in rename mode
* \return KviClassEditorFunctionDialog
*/
diff --git a/src/modules/dcc/DccMarshal.cpp b/src/modules/dcc/DccMarshal.cpp
index 552bfd4d8..0575ab9e5 100644
--- a/src/modules/dcc/DccMarshal.cpp
+++ b/src/modules/dcc/DccMarshal.cpp
@@ -484,7 +484,7 @@ void DccMarshal::snActivated(int)
emit error(eError);
return;
}
- //Succesfully connected...
+ //Successfully connected...
delete m_pSn;
m_pSn = 0;
// get the local address
diff --git a/src/modules/dcc/DccVoiceAdpcmCodec.cpp b/src/modules/dcc/DccVoiceAdpcmCodec.cpp
index 0d4907313..2ac4f4156 100644
--- a/src/modules/dcc/DccVoiceAdpcmCodec.cpp
+++ b/src/modules/dcc/DccVoiceAdpcmCodec.cpp
@@ -44,7 +44,7 @@
//
// Intel/DVI ADPCM coder/decoder.
//
-// The algorithm for this coder was taken from the IMA Compatability Project
+// The algorithm for this coder was taken from the IMA Compatibility Project
// proceedings, Vol 2, Number 2; May 1992.
//
// Version 1.2, 18-Dec-92.
diff --git a/src/modules/dcc/libkvidcc.cpp b/src/modules/dcc/libkvidcc.cpp
index a1c269f48..4115225c7 100644
--- a/src/modules/dcc/libkvidcc.cpp
+++ b/src/modules/dcc/libkvidcc.cpp
@@ -627,7 +627,7 @@ static bool dcc_kvs_cmd_send(KviKvsModuleCommandCall * c)
if(pSw->asInteger(iSize)) // is an integer
{
pSw->asString(szTmp);
- // avoid sprintf as long as possibile
+ // avoid sprintf as long as possible
d->szFileSize = szTmp;
} else {
d->szFileSize = __tr_ctx("<unknown size>","dcc");
diff --git a/src/modules/filetransferwindow/FileTransferWindow.cpp b/src/modules/filetransferwindow/FileTransferWindow.cpp
index ada35883d..9603d4e7a 100644
--- a/src/modules/filetransferwindow/FileTransferWindow.cpp
+++ b/src/modules/filetransferwindow/FileTransferWindow.cpp
@@ -592,7 +592,7 @@ void FileTransferWindow::openLocalFileTerminal()
if(idx == -1)return;
tmp = tmp.left(idx);
tmp.append("\"");
- // FIXME: this is not a solution ...because if the drive isn't system's drive the command 'cd' naturaly doesn't work
+ // FIXME: this is not a solution ...because if the drive isn't system's drive the command 'cd' naturally doesn't work
tmp.prepend("cmd.exe /k cd \"");
system(tmp.toLocal8Bit().data());
#else
diff --git a/src/modules/mediaplayer/MpMprisInterface.cpp b/src/modules/mediaplayer/MpMprisInterface.cpp
index 43faeee09..6c40d47ec 100644
--- a/src/modules/mediaplayer/MpMprisInterface.cpp
+++ b/src/modules/mediaplayer/MpMprisInterface.cpp
@@ -30,7 +30,7 @@
according to MPRIS 1.0, GetStatus returns struct of 4 integers.
First integer: 0 = Playing, 1 = Paused, 2 = Stopped.
- Second interger: 0 = Playing linearly, 1 = Playing randomly.
+ Second integer: 0 = Playing linearly, 1 = Playing randomly.
Third integer: 0 = Go to the next element once the current has finished playing, 1 = Repeat the current element
Fourth integer: 0 = Stop playing once the last element has been played, 1 = Never give up playing
*/
@@ -195,7 +195,7 @@ QString MpMprisInterface::nowPlaying()
if (v.userType() == QVariant::Map) {
const QVariantMap map = v.toMap();
QVariantMap::ConstIterator it = map.constBegin();
- for ( ; it != map.constEnd(); ++it) { /* maybe do some configureable formatting */
+ for ( ; it != map.constEnd(); ++it) { /* maybe do some configurable formatting */
if (it.key() == "artist")
artist = it.value().toString();
else if (it.key() == "title")
@@ -344,7 +344,7 @@ bool MpAudaciousInterface::quit()
if (MpMprisInterface::quit())
return true;
- /* compability with older versions */
+ /* compatibility with older versions */
MPRIS_SIMPLE_CALL("/Player", "Quit")
}
@@ -378,7 +378,7 @@ MpInterface::PlayerStatus MpAudaciousInterface::status()
if (status != MpInterface::Unknown)
return status;
- /* compability with older versions */
+ /* compatibility with older versions */
QDBusInterface dbus_iface(m_szServiceName, "/Player",
"org.freedesktop.MediaPlayer", QDBusConnection::sessionBus());
if (!dbus_iface.isValid())
@@ -400,7 +400,7 @@ int MpAudaciousInterface::length()
if (length != -1)
return length;
- /* compability with older versions */
+ /* compatibility with older versions */
MPRIS_CALL_METHOD("GetMetadata", -1)
foreach (QVariant w, reply.arguments()) {
diff --git a/src/modules/mediaplayer/libkvimediaplayer.cpp b/src/modules/mediaplayer/libkvimediaplayer.cpp
index 908f7914d..77b884d7f 100644
--- a/src/modules/mediaplayer/libkvimediaplayer.cpp
+++ b/src/modules/mediaplayer/libkvimediaplayer.cpp
@@ -622,7 +622,7 @@ MP_KVS_COMMAND(amipExec)
@seealso:
[module:mediaplayer]media player module documentation[/module],
[fnc]$mediaplayer.position[/fnc],
- [fnc]$mediaplayer.lenght[/fnc],
+ [fnc]$mediaplayer.length[/fnc],
*/
MP_KVS_COMMAND(jumpTo)
diff --git a/src/modules/objects/KvsObject_label.cpp b/src/modules/objects/KvsObject_label.cpp
index 57e35b0e2..6278a029a 100644
--- a/src/modules/objects/KvsObject_label.cpp
+++ b/src/modules/objects/KvsObject_label.cpp
@@ -177,7 +177,7 @@ const int frame_cod[] = {
Sets the image to be displayed on this label.
Giving empty argument clears the pixmap.[br]
See the [doc:image_id]image identifier[/doc] documentation for
- the explaination of the <image_id> parameter.
+ the explanation of the <image_id> parameter.
*/
diff --git a/src/modules/objects/KvsObject_listWidget.cpp b/src/modules/objects/KvsObject_listWidget.cpp
index b3789b41b..7b846df13 100644
--- a/src/modules/objects/KvsObject_listWidget.cpp
+++ b/src/modules/objects/KvsObject_listWidget.cpp
@@ -92,7 +92,7 @@ const char * const itemflags_tbl[] = {
!fn: $setFlag(<idx:integer>,<flag1:string>, <flag2:string>, ...)
Sets the flags for the item at index idx to the given flags. These determine whether the item can be selected or modified. This is often used to disable an item.[br]
Supported flags are:
- [exmaple]
+ [example]
[br]- noitemflag : no flag sets;
[br]- selectable : item is selectable;
[br]- editable : item is editable;
diff --git a/src/modules/objects/KvsObject_radioButton.cpp b/src/modules/objects/KvsObject_radioButton.cpp
index 787a7a270..e26f3c108 100644
--- a/src/modules/objects/KvsObject_radioButton.cpp
+++ b/src/modules/objects/KvsObject_radioButton.cpp
@@ -52,7 +52,7 @@
!fn: $setChecked(<bChecked:boolean>)
Sets whether the radio button is checked to check.
!fn: $setPixmap(<image_id>)
- Sets the pixmap shown on the radiobutton..See the [doc:image_id]image identifier[/doc] documentation for the explaination
+ Sets the pixmap shown on the radiobutton..See the [doc:image_id]image identifier[/doc] documentation for the explanation
of the <image_id> parameter.
!fn: <bool>$toggleEvent()
Called by KVIrc when the radibutton state is toggled.
diff --git a/src/modules/objects/KvsObject_socket.cpp b/src/modules/objects/KvsObject_socket.cpp
index 8f1340172..7dfe40c00 100644
--- a/src/modules/objects/KvsObject_socket.cpp
+++ b/src/modules/objects/KvsObject_socket.cpp
@@ -220,7 +220,7 @@ const char * const sockerrors_tbl[] = {
{
// incoming connection socket passed by the framework
%socket = $0
- debug "Webserver incoming Conection from: %socket->$remoteIp : %socket->$remotePort"
+ debug "Webserver incoming Connection from: %socket->$remoteIp : %socket->$remotePort"
%socket->$write("HTTP/1.0 200 OK\n\n<html><head></head><body><h1>KVIrc Webserver</h1></body></html>\n")
// tells KVIrc no need this socket anymore
return $true()
diff --git a/src/modules/options/OptionsInstanceManager.cpp b/src/modules/options/OptionsInstanceManager.cpp
index 1c2d3dd58..bb5743dc2 100644
--- a/src/modules/options/OptionsInstanceManager.cpp
+++ b/src/modules/options/OptionsInstanceManager.cpp
@@ -3672,7 +3672,7 @@ void OptionsInstanceManager::deleteInstanceTree(KviPointerList<OptionsWidgetInst
} else {
qDebug("Ops...i have deleted the options dialog ?");
}
- } //else qDebug("Clas %s has no widget",e->szName);
+ } //else qDebug("Class %s has no widget",e->szName);
if(pEntry->pChildList)
deleteInstanceTree(pEntry->pChildList);
}
diff --git a/src/modules/options/mkcreateinstanceproc.sh b/src/modules/options/mkcreateinstanceproc.sh
index 7737a0516..7e70cd6b8 100755
--- a/src/modules/options/mkcreateinstanceproc.sh
+++ b/src/modules/options/mkcreateinstanceproc.sh
@@ -322,7 +322,7 @@ void OptionsInstanceManager::deleteInstanceTree(KviPointerList<OptionsWidgetInst
} else {
qDebug("Ops...i have deleted the options dialog ?");
}
- } //else qDebug("Clas %s has no widget",e->szName);
+ } //else qDebug("Class %s has no widget",e->szName);
if(pEntry->pChildList)
deleteInstanceTree(pEntry->pChildList);
}
diff --git a/src/modules/perl/libkviperl.cpp b/src/modules/perl/libkviperl.cpp
index ef2df64ce..3e8f3c834 100644
--- a/src/modules/perl/libkviperl.cpp
+++ b/src/modules/perl/libkviperl.cpp
@@ -199,7 +199,7 @@
Sets KVIrc's local variable %x to &lt;value&gt;[br]
&nbsp; &nbsp; [b]KVIrc::setGlobal(&lt;Y&gt;,&lt;value&gt;)[/b][br]
Sets KVIrc's global variable %Y to &lt;value&gt;[br]
- The local variables referenced belong to the current KVS exection context
+ The local variables referenced belong to the current KVS execution context
while the global variables are visible everywhere.[br]
[example]
%pippo = test
@@ -388,7 +388,7 @@
If <perl_context> is specified then a Perl interpreter
keyed to that context is used: if it was already existing
then it is reused otherwise it is created.
- Any <perl_context> is persistent: it mantains the function
+ Any <perl_context> is persistent: it maintains the function
declarations and Perl variable states until explicitly
destroyed with [cmd]perl.destroy[/cmd] (or the perlcore
module is forcibly unloaded).[br]
diff --git a/src/modules/perlcore/CMakeLists.txt b/src/modules/perlcore/CMakeLists.txt
index c971381e1..82652138a 100644
--- a/src/modules/perlcore/CMakeLists.txt
+++ b/src/modules/perlcore/CMakeLists.txt
@@ -17,7 +17,7 @@ if(CMAKE_COMPILER_IS_GNUCXX)
set(PERL_COMPILE_FLAGS "${PERL_COMPILE_FLAGS} -Wno-literal-suffix")
elseif("${CMAKE_CXX_COMPILER_ID}" MATCHES "Clang")
# If the perl version is too old, clang will throw errors due to C++11
- # incompatiblities
+ # incompatibilities
set(PERL_COMPILE_FLAGS "${PERL_COMPILE_FLAGS} -Wno-reserved-user-defined-literal")
endif()
diff --git a/src/modules/python/libkvipython.cpp b/src/modules/python/libkvipython.cpp
index a90c0b071..f322cba00 100644
--- a/src/modules/python/libkvipython.cpp
+++ b/src/modules/python/libkvipython.cpp
@@ -127,7 +127,7 @@
[br]
In the example above, KVIrc creates an interpreter when [cmd]python.begin[/cmd]
is invoked and destroys it at [cmd]python.end[/cmd] parsing time.
- In fact, KVIrc can mantain multiple persistent interpreters that will
+ In fact, KVIrc can maintain multiple persistent interpreters that will
allow you to preserve your context across [cmd]python.begin[/cmd] invocations.[br]
[br]
You can invoke a specific Python context by passing it as parameter to the [cmd]python.begin[/cmd]
@@ -199,7 +199,7 @@
Sets KVIrc's local variable %x to &lt;value&gt;[br]
&nbsp; &nbsp; [b]kvirc.setGlobal(&lt;Y&gt;,&lt;value&gt;)[/b][br]
Sets KVIrc's global variable %Y to &lt;value&gt;[br]
- The local variables referenced belong to the current KVS exection context
+ The local variables referenced belong to the current KVS execution context
while the global variables are visible everywhere.[br]
[example]
%pippo = test
diff --git a/src/modules/str/libkvistr.cpp b/src/modules/str/libkvistr.cpp
index bfc185366..2fe470df8 100644
--- a/src/modules/str/libkvistr.cpp
+++ b/src/modules/str/libkvistr.cpp
@@ -1173,7 +1173,7 @@ static bool str_kvs_fnc_word(KviKvsModuleFunctionCall * c)
QString szString;
kvs_int_t iOccurence;
KVSM_PARAMETERS_BEGIN(c)
- KVSM_PARAMETER("occurence",KVS_PT_INT,0,iOccurence)
+ KVSM_PARAMETER("occurrence",KVS_PT_INT,0,iOccurence)
KVSM_PARAMETER("string",KVS_PT_STRING,0,szString)
KVSM_PARAMETERS_END(c)
int idx = 0;
diff --git a/src/modules/torrent/libkvitorrent.cpp b/src/modules/torrent/libkvitorrent.cpp
index 969c0cdcb..aacd461c8 100644
--- a/src/modules/torrent/libkvitorrent.cpp
+++ b/src/modules/torrent/libkvitorrent.cpp
@@ -69,7 +69,7 @@ static TorrentInterface *auto_detect_torrent_client(KviWindow * pOut = 0)
/* if(iBest < 90)
{
if(pOut)
- pOut->outputNoFmt(KVI_OUT_MULTIMEDIA,__tr2qs_ctx("Not sure about the results, trying a second, more agressive detection pass","torrent"));
+ pOut->outputNoFmt(KVI_OUT_MULTIMEDIA,__tr2qs_ctx("Not sure about the results, trying a second, more aggressive detection pass","torrent"));
// no sure player found... try again with a destructive test
for(d = g_pDescriptorList->first();d;d = g_pDescriptorList->next())
{
diff --git a/src/modules/window/libkviwindow.cpp b/src/modules/window/libkviwindow.cpp
index 6879b4287..7f23dfb71 100644
--- a/src/modules/window/libkviwindow.cpp
+++ b/src/modules/window/libkviwindow.cpp
@@ -265,7 +265,7 @@ static bool window_kvs_cmd_activate(KviKvsModuleCommandCall * c)
does not exist a warning is printed unless the -q switch is used.
If the window is currently docked in a frame then the frame's
system taskbar entry will be flashed.
- Please note that this command is highly system dependant:
+ Please note that this command is highly system dependent:
on systems that do not have a system taskbar or there
is no way to flash an entry this command will do nothing.
At the time of writing this command works flawlessly on
@@ -299,7 +299,7 @@ static bool window_kvs_cmd_demandAttention(KviKvsModuleCommandCall * c)
Returns the current activity level of the window specified by <window_id>.
The form without parameters works on the current window.[br]
The activity level is a number describing the level of traffic in the window
- and depends on the window type. On channels and queries it is dependant on the number
+ and depends on the window type. On channels and queries it is dependent on the number
and frequency of actions performed by the users.
@seealso:
[fnc]$window.activityTemperature[/fnc]
diff --git a/src/kvilib/core/KviCString.h b/src/kvilib/core/KviCString.h
index 895d1ffd8..fa6685406 100644
--- a/src/kvilib/core/KviCString.h
+++ b/src/kvilib/core/KviCString.h
@@ -307,7 +307,7 @@ public:
// & paste
KviCString & insert(int idx,const char *data);
KviCString & insert(int idx,char c);
//Replaces all occurences of char c with the string str
KviCString & replaceAll(const char c,const char *str);
//same as above but with a string
KviCString & replaceAll(const char *toFind,const char *str,bool bCaseS = true);
@@ -317,13 +317,13 @@ public:
// Strips whitespace characters from beginning of this string.
KviCString & stripLeftWhiteSpace();
KviCString & stripRightWhiteSpace();
- // Stips inital and final WHITESPACE characters (see man isspace),<br>
+ // Stips initial and final WHITESPACE characters (see man isspace),<br>
// and returns a reference to this string.
KviCString & trim();
// Strips spaces and tabs only
KviCString & stripSpace();
// Strips all occurences of the character c from the beginning of the string.<br>
// Note that c can not be '\0' :)
KviCString & stripLeft(char c);
KviCString & stripRight(char c);
@@ -369,35 +369,35 @@ public:
KviCString & hexDecode(){ return hexDecode(m_ptr); };
//=============================================================================
- // Contains / occurence count
+ // Contains / occurrence count
//=============================================================================
- // Returns true if at least one occurence of str is found
+ // Returns true if at least one occurrence of str is found
bool contains(const char *str,bool caseS=true) const;
- // Returns true if at least one occurence of character c is found in this string
+ // Returns true if at least one occurrence of character c is found in this string
bool contains(char c,bool caseS=true) const;
// Returns the number of occurences of string str in this string.<br>
// Overlapped matches are counted.
- int occurences(const char *str,bool caseS=true) const;
- // Returns the number of occurences of character c in this string
- int occurences(char c,bool caseS=true) const;
+ int occurrences(const char *str,bool caseS=true) const;
+ // Returns the number of occurrences of character c in this string
+ int occurrences(char c,bool caseS=true) const;
//=============================================================================
// Find
//=============================================================================
- // Finds the first occurence of the character c in this string,<br>
+ // Finds the first occurrence of the character c in this string,<br>
// and returns its zero-based index or -1 if c can not be found.<br>
// c can NOT be '\0' here.
int findFirstIdx(char c) const;
- // Finds the first occurence of the sub-string str in this string,<br>
+ // Finds the first occurrence of the sub-string str in this string,<br>
// and returns its zero-based index or -1 if the sub-string can not be found.<br>
// str can NOT be 0 here.
int findFirstIdx(const char *str,bool caseS = true) const;
- // Finds the last occurence of the character c in this string,<br>
+ // Finds the last occurrence of the character c in this string,<br>
// and returns its zero-based index or -1 if the character can not be found.
int findLastIdx(char c) const;
- // Finds the last occurence of the sub-string str in this string,<br>
+ // Finds the last occurrence of the sub-string str in this string,<br>
// and returns its zero-based index or -1 if the sub-string can not be found.<br>
// str can NOT be 0 here.
int findLastIdx(const char *str,bool caseS = true) const;
@@ -432,7 +432,7 @@ public:
KviCString & setNum(char num) { return setNum((long)num); };
KviCString & setNum(unsigned char num) { return setNum((unsigned long)num); };
- // Retuns true if the string contains only digits and an optional '-' character
+ // Returns true if the string contains only digits and an optional '-' character
// at the beginning.<be>
// Space characters are allowed at the begginning and the end.<br>
// There is no overflow check!
@@ -307,7 +307,7 @@ public:
KviCString & insert(int idx,const char *data);
KviCString & insert(int idx,char c);
- //Replaces all occurences of char c with the string str
+ //Replaces all occurrences of char c with the string str
KviCString & replaceAll(const char c,const char *str);
//same as above but with a string
@@ -317,13 +317,13 @@ public:
// Strips spaces and tabs only
KviCString & stripSpace();
- // Strips all occurences of the character c from the beginning of the string.<br>
+ // Strips all occurrences of the character c from the beginning of the string.<br>
// Note that c can not be '\0' :)
KviCString & stripLeft(char c);
@@ -369,35 +369,35 @@ public:
bool contains(char c,bool caseS=true) const;
- // Returns the number of occurences of string str in this string.<br>
+ // Returns the number of occurrences of string str in this string.<br>
// Overlapped matches are counted.